/*
  ADAU1701_I2C - Library for communicating with the ADAU1701.
  The ADAU1701 uses 16-bit addressing, so the simple wire instructions aren't adequate.  These routines
     provide the 16-bit addressing.

     These routines use the Wire library, which must be initialized separately.

  Created by Neil Davis, December, 2020.
*/

#ifndef ADAU1701_I2C_H
#define ADAU1701_I2C_H

#include "Arduino.h"
extern bool setup_done;

class ADAU1701_I2C
{
  public:
    ADAU1701_I2C(uint8_t I2C_addr);

    void Read_block(byte MSB, byte LSB, uint8_t (&Data_block)[16], int count);
    void I2C_write_Mult(uint8_t addr_MSB, uint8_t addr_LSB, uint8_t count, uint8_t command_buffer[]);
    void safeload_addr(word v_reg, byte safeload_reg_num);
    void safeload_data(byte safeload_reg_num, uint8_t safeload_data_array[]);
    void biquad_safe_load(word filter_reg, byte ADAU1701_coefs [5][4]);
    void safeload_xfer();
    void ADAU1701_soft_reset();
    void Load_program(const byte* Prog_table_pointer);
    void Load_parameters(const byte* Param_table_pointer);
    void Load_registers();
    

  private:
    //these are values that need to get set and stay set after initialization, since they get used later
    uint8_t _I2C_addr;

    //Routines used internally
    void ADAU1701_write_table( const byte* t_base, byte inst_len);
};

#endif
